Module errors

Module errors 

Contains all error-related functionality of the crate.

Structs

DateTimeNotRepresentable
Occurs if a DateTime is not representable as a Timestamp.
ParseLineError
The error that occurs when a line of a leap-seconds.list file could not be parsed.

Enums

DataComponent
Data that is required to exist exactly once in a leap-seconds.list file.
InvalidDate
Indicates an attempt to create an invalid Date.
InvalidTime
Indicates and attempt to create an invalid Time.
ParseFileError
Indicates that a leap-seconds.list file could not be parsed successfully.
ParseLineErrorKind
Reasons that could cause a line to not be parsed successfully.