ParseFileError

Enum ParseFileError 

pub enum ParseFileError {
    IoError(Error),
    ParseLineError(ParseLineError),
    InvalidHash {
        calculated: Sha1Hash,
        found: Sha1Hash,
    },
    MissingData(DataComponent),
    DuplicateData {
        data_component: DataComponent,
        line1: usize,
        line2: usize,
    },
}
Indicates that a leap-seconds.list file could not be parsed successfully.

Variants



IoError(Error)

An IO error occurred in the underlying stream.



ParseLineError(ParseLineError)

A line in the file could not be parsed successfully.

See ParseLineError for further information.



InvalidHash

The hash that was calculated did not match the one that was found in the file.

Fields

calculated: Sha1Hash

The hash that was calculated from the contents of the file.

found: Sha1Hash

The hash that was found in the file.



MissingData(DataComponent)

The given file is incomplete. Required data could not be found in the file.



DuplicateData

The file contains duplicate data.

Fields

data_component: DataComponent

The type of data that was found twice.

line1: usize

The first line the data was found on.

line2: usize

The second line the data was found on.