pub enum ParseLineErrorKind {
InvalidTimestamp,
InvalidLeapSecondLine,
InvalidTaiDiff,
InvalidHash,
}Expand description
Reasons that could cause a line to not be parsed successfully.
Variants
InvalidTimestamp
A timestamp is incorrectly formatted.
InvalidLeapSecondLine
A line describing a leap second is incorrectly formatted.
InvalidTaiDiff
InvalidHash
The line containing the hash of the data is incorrectly formatted.