pub struct ParseLineError { /* private fields */ }Expand description
The error that occurs when a line of a leap-seconds.list file could not be parsed.
Implementations
Sourceimpl ParseLineError
impl ParseLineError
Sourcepub const fn cause(&self) -> ParseLineErrorKind
pub const fn cause(&self) -> ParseLineErrorKind
Gets what caused this error.
Sourcepub const fn line_number(&self) -> usize
pub const fn line_number(&self) -> usize
Gets the line number at which this error occured.