Contains all error-related functionality of the crate.
Structs
- Date
Time NotRepresentable - Occurs if a
DateTimeis not representable as aTimestamp. - Parse
Line Error - The error that occurs when a line of a
leap-seconds.listfile could not be parsed.
Enums
- Data
Component - Data that is required to exist exactly once in a
leap-seconds.listfile. - Invalid
Date - Indicates an attempt to create an invalid
Date. - Invalid
Time - Indicates and attempt to create an invalid
Time. - Parse
File Error - Indicates that a
leap-seconds.listfile could not be parsed successfully. - Parse
Line Error Kind - Reasons that could cause a line to not be parsed successfully.