pub enum DataComponent {
LastUpdate,
ExpirationDate,
Hash,
}Expand description
Data that is required to exist exactly once in a leap-seconds.list file.
If that is not the case, an attempt to parse the file will result in a ParseFileError.
Variants
LastUpdate
A line containing a timestamp when the file was updated last.
ExpirationDate
A timestamp at which the data in the file expires.
Hash
A hash of the data contained in the file.