pub enum ParseFileError {
IoError(Error),
ParseLineError(ParseLineError),
InvalidHash {
calculated: Sha1Hash,
found: Sha1Hash,
},
MissingData(DataComponent),
DuplicateData {
data_component: DataComponent,
line1: usize,
line2: usize,
},
}Expand description
Indicates that a leap-seconds.list file could not be parsed successfully.
Variants
IoError(Error)
An IO error occurred in the underlying stream.
ParseLineError(ParseLineError)
A line in the file could not be parsed successfully.
See ParseLineError for further information.
InvalidHash
The hash that was calculated did not match the one that was found in the file.
Fields
MissingData(DataComponent)
The given file is incomplete. Required data could not be found in the file.
DuplicateData
The file contains duplicate data.